<?php

namespace Drupal\Tests\eca_base\Kernel;

use Drupal\eca\Service\Conditions;
use Drupal\KernelTests\KernelTestBase;

/**
 * Kernel tests for the "eca_token_set_value" action plugin.
 *
 * @group eca
 * @group eca_base
 */
class TokenSetValueTest extends KernelTestBase {

  /**
   * The modules.
   *
   * @var string[]
   *   The modules.
   */
  protected static $modules = [
    'system',
    'eca',
    'eca_base',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->installConfig(static::$modules);
  }

  /**
   * Tests TokenSetValue.
   */
  public function testTokenSetValue(): void {
    /** @var \Drupal\Core\Action\ActionManager $action_manager */
    $action_manager = \Drupal::service('plugin.manager.action');
    /** @var \Drupal\eca\Token\TokenInterface $token_services */
    $token_services = \Drupal::service('eca.token_services');

    $random_string = $this->randomString();
    /** @var \Drupal\eca_base\Plugin\Action\TokenSetValue $action */
    $action = $action_manager->createInstance('eca_token_set_value', [
      'token_name' => 'my_custom_token:value1',
      'token_value' => $random_string,
      'use_yaml' => Conditions::OPTION_NO,
    ]);
    $this->assertTrue($action->access(NULL));
    $action->execute(NULL);
    $this->assertEquals($random_string, $token_services->replaceClear('[my_custom_token:value1]'));
    $this->assertEquals('', $token_services->replaceClear('[my_custom_token:value2]'));

    /** @var \Drupal\eca_base\Plugin\Action\TokenSetValue $action */
    $action = $action_manager->createInstance('eca_token_set_value', [
      'token_name' => 'my_custom_token:value2',
      'token_value' => $random_string . '123',
      'use_yaml' => Conditions::OPTION_NO,
    ]);
    $this->assertTrue($action->access(NULL));
    $action->execute(NULL);
    $this->assertEquals($random_string, $token_services->replaceClear('[my_custom_token:value1]'));
    $this->assertEquals($random_string . '123', $token_services->replaceClear('[my_custom_token:value2]'));

    $this->assertEquals("${random_string}, ${random_string}123", $token_services->replace('[my_custom_token]'));

    $yaml_string = <<<YAML
key1: "Hello"
key2: "[my_custom_token:value1]"
YAML;

    /** @var \Drupal\eca_base\Plugin\Action\TokenSetValue $action */
    $action = $action_manager->createInstance('eca_token_set_value', [
      'token_name' => 'object_token',
      'token_value' => $yaml_string,
      'use_yaml' => Conditions::OPTION_YES,
    ]);
    $this->assertTrue($action->access(NULL));
    $action->execute(NULL);
    $this->assertEquals('Hello', $token_services->replaceClear('[object_token:key1]'));
    $this->assertEquals($random_string, $token_services->replaceClear('[object_token:key2]'));
  }

}
