<?php

namespace Drupal\eca_content\Event;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\eca_content\Service\EntityTypes;

/**
 * Provides an event when a content entity form is being prepared.
 *
 * @package Drupal\eca_content\Event
 */
class ContentEntityPrepareForm extends ContentEntityBaseEntity {

  /**
   * The operation.
   *
   * @var string
   */
  protected string $operation;

  /**
   * The form state.
   *
   * @var \Drupal\Core\Form\FormStateInterface
   */
  protected FormStateInterface $formState;

  /**
   * Constructor.
   *
   * @param \Drupal\Core\Entity\ContentEntityInterface $entity
   *   The entity.
   * @param \Drupal\eca_content\Service\EntityTypes $entity_types
   *   The entity types.
   * @param string $operation
   *   The operation.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public function __construct(ContentEntityInterface $entity, EntityTypes $entity_types, string $operation, FormStateInterface $form_state) {
    parent::__construct($entity, $entity_types);
    $this->operation = $operation;
    $this->formState = $form_state;
  }

  /**
   * Gets the operation.
   *
   * @return string
   *   The operation.
   */
  public function getOperation(): string {
    return $this->operation;
  }

  /**
   * Gets the form state.
   *
   * @return \Drupal\Core\Form\FormStateInterface
   *   The form state.
   */
  public function getFormState(): FormStateInterface {
    return $this->formState;
  }

}
