<?php

namespace Drupal\eca_ui\Service;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;

/**
 * Service class for Token Browser in ECA.
 */
class TokenBrowserService {

  /**
   * Module handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected ModuleHandlerInterface $moduleHandler;

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * List of token types.
   *
   * @var array
   */
  protected array $tokenTypes = [];

  /**
   * Constructs the token browser service.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler service.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager service.
   */
  public function __construct(ModuleHandlerInterface $moduleHandler, EntityTypeManagerInterface $entityTypeManager) {
    $this->moduleHandler = $moduleHandler;
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * Returns the markup needed for the token browser.
   *
   * @return array
   *   Markup for the token browser.
   */
  public function getTokenBrowserMarkup(): array {
    if (!$this->moduleHandler->moduleExists('token')) {
      return [];
    }

    return [
      'tb' => [
        '#type' => 'container',
        '#theme' => 'token_tree_link',
        '#token_types' => $this->getTokenTypes(),
      ],
    ];
  }

  /**
   * Gets all token types based on all available entity types.
   *
   * @return array
   *   The list of token types.
   */
  private function getTokenTypes(): array {
    if (!$this->tokenTypes) {
      $this->tokenTypes = [];
      foreach ($this->entityTypeManager->getDefinitions() as $definition) {
        $this->tokenTypes[] = $definition->get('id');
      }
    }
    return $this->tokenTypes;
  }

}
